@@ -123,7 +123,7 @@ class Storage(storage.Storage):
             # if not there, copy from the defaults
             try:
                 import defs
-                data_dir = os.path.join(defs.DATA_DIR, "hamster-applet")
+                data_dir = os.path.join(defs.DATA_DIR, "hamster-time-tracker")
             except:
                 # if defs is not there, we are running from sources
                 module_dir = os.path.dirname(os.path.realpath(__file__))
@@ -617,7 +617,7 @@ class Storage(storage.Storage):
 
         #now link tags
         insert = ["insert into fact_tags(fact_id, tag_id) values(?, ?)"] * len(tags)
-        params = [(fact_id, tag["id"]) for tag in tags]
+        params = [(fact_id, tag[0]) for tag in tags]
         self.execute(insert, params)
 
         self.__remove_index([fact_id])
